@@ -7,23 +7,49 @@
 import yagmail
 import json
 import requests
-from loguru import logger
 
-def json_util(pre_json, to_json_type, **kwargs):
+
+def send_mail_util(from_user, pwd, host, to_user, subject, content):
     """
-    json解析
-    :param pre_json:
-    :param to_json_type:
-    :param kwargs:
+    发送邮件
+    :param from_user: 发件人
+    :param pwd: 密码
+    :param host: 发件地址host
+    :param to_user: 接收人
+    :param subject: 邮件主题
+    :param content: 邮件内容
     :return:
     """
+    with yagmail.SMTP(user=from_user, password=pwd, host=host) as yag:
+        yag.send(to_user, subject, content)
+
+def json_util(pre_json, to_json_type, **kwargs):
     try:
         return json.loads(pre_json) if to_json_type == 'json_load' else json.dumps(
             pre_json, ensure_ascii=False, **kwargs)
     except:
         return pre_json
 
+def trans_data_to_url_util(url, data):
+    """
+    参数转成url形式展示拼接
+    :param url:
+    :param data:
+    :return:
+    """
+    if data:
+        url = f'{url}?{"&".join([f"{k}={v}" for k, v in data.items()])}'
+    return url
+
 def http_client_util(url, method, data, **kwargs):
+    """
+    http请求
+    :param url:
+    :param method:
+    :param data:
+    :param kwargs:
+    :return:
+    """
     up_method = method.upper()
     if up_method == 'POST':
         res = requests.post(url, data=data, **kwargs)
@@ -42,34 +68,9 @@ def http_client_util(url, method, data, **kwargs):
     res.encoding = 'utf-8'
     return res
 
-def trans_data_to_url_util(url, data):
+def send_robot_msg_util(msg, send_type, at_all, qy_wechat_token=''):
     """
-    参数转成url形式展示拼接
-    :param url:
-    :param data:
-    :return:
-    """
-    if data:
-        url = f'{url}?{"&".join([f"{k}={v}" for k, v in data.items()])}'
-    return url
-
-def send_mail_util(from_user, pwd, host, to_user, subject, content):
-    """
-    发送邮件
-    :param from_user: 发件人
-    :param pwd: 密码
-    :param host: 发件地址host
-    :param to_user: 接收人
-    :param subject: 邮件主题
-    :param content: 邮件内容
-    :return:
-    """
-    with yagmail.SMTP(user=from_user, password=pwd, host=host) as yag:
-        yag.send(to_user, subject, content)
-
-def send_robot_msg_util(msg, send_type, at_alls, qy_wechat_token=''):
-    """
-    企业微信机器人 webhook
+    # webhook机器人
     :param msg:
     :param send_type:
     :param at_all:
@@ -78,16 +79,9 @@ def send_robot_msg_util(msg, send_type, at_alls, qy_wechat_token=''):
     """
     payloads = {"msgtype": "text", "text": {"content": msg}}
     if send_type == 'qyWechat':
-        payloads['text']['mentioned_mobile_list'] = ['@all'] if at_alls is True else at_alls
+        payloads['text']['mentioned_mobile_list'] = ['@all'] if at_all is True else at_all
         url = 'https://qyapi.weixin.qq.com/cgi-bin/webhook/send'
         pre_data = {'key': qy_wechat_token}
-
-    url = trans_data_to_url_util(url, pre_data)
-    data = json_util(payloads, 'json_dump').encode('utf-8')
-    http_client_util(url, 'POST', data=data, headers={'Content-Type': 'application/json'})
-
-def logger_util(msg):
-    """
-    日志相关
-    """
-    logger.info(f'\n{msg}')
\ No newline at end of file
+        url = trans_data_to_url_util(url, pre_data)
+        data = json_util(payloads, 'json_dump').encode('utf-8')
+        http_client_util(url, 'POST', data=data, headers={'Content-Type': 'application/json'})
